/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.geolocation.business;

import java.util.List;
import org.ow2.util.geolocation.business.entity.GeolocalisedProduct;

/**
 * Interface of the geolocalization EJB.
 * 
 * @author mancelin
 */
public interface GeoLocatorInterface {
    /**
     * Add a new record in the app.
     * @param ipAddress the address of the user.
     * @param productName the product name.
     * @param productVersion the version name.
     * @param email the email address of the user.
     * @param jreVendor the jre vendor.
     * @param jreVersion the jre version.
     * @param jvmName the jvm name.
     * @param jvmVendor the jvm vendor.
     * @param jvmVersion the jvm version.
     * @param osName the os.
     * @param osArch os architecture.
     * @param osVersion os version.
     * @param numProc the number of processors.
     * @return succeed
     */
    boolean addNewRecord(
            final String ipAddress,
            final String productName,
            final String productVersion,
            final String email,
            final String numProc,
            final String jreVersion,
            final String jreVendor,
            final String jvmVersion,
            final String jvmVendor,
            final String jvmName,
            final String osName,
            final String osArch,
            final String osVersion);
    /**
     * @param productName the product name.
     * @param productVersion the product version.
     * @return filtered list of products.
     */
    List getLocalisedProducts(java.lang.String productName, java.lang.String productVersion);
    /**
     * @return all products name.
     */
    List findAllProductsName();
    /**
     * @return all products versions.
     */
    List findAllProductsVersions();
    /**
     * Remove a product.
     * @param id the id product.
     */
    void removeProduct(Long id);

    /**
     * Add a managed product in the managed products list.
     * @param name name of the product.
     * @param version version of the product.
     * @return succeed
     */
    boolean addManagedProduct(final String name, final String version);

    /**
     *
     * @param productName the filter name.
     * @param productVersion the filter version.
     * @return all persited products with the right name and right version.
     */
    List findManagedProductsWithNameAndVersion(final String productName, final String productVersion);

    /**
     * Remove a managed product.
     * @param id the id of the managed product.
     */
    void removeManagedProduct(final Long id);

    /**
     * @return all persited managed products.
     */
    List findAllManagedProducts();

    /**
     * @param id id of the product.
     * @return a specific product.
     */
    GeolocalisedProduct findAProduct(final String id);

}
