/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.geolocation.business.entity;

import java.io.Serializable;
import java.util.List;
import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;

/**
 * The name of a product.
 * 
 * @author mancelin
 */
@Entity
public class ProductName implements Serializable {
    /**
     * The version UID.
     */
    private static final long serialVersionUID = 1L;
    /**
     * The name of the product name.
     */
    private String name = "";
    /**
     * The id of the product name.
     */
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;
    /**
     * The concerned list of products.
     */
    @OneToMany(mappedBy = "productName", cascade = CascadeType.REMOVE, fetch = FetchType.LAZY)
    private List<GeolocalisedProduct> products;
    /**
     * @return the id of the product name.
     */
    public Long getId() {
        return id;
    }
    /**
     * Set the id of the product name.
     * @param id the id of the product name.
     */
    public void setId(final Long id) {
        this.id = id;
    }
    
    @Override
    public int hashCode() {
        int hash = 0;
        if (id != null) {
            hash += id.hashCode();
        } else {
            hash += 0;
        }
        return hash;
    }

    @Override
    public boolean equals(final Object object) {
        if (!(object instanceof ProductName)) {
            return false;
        }
        ProductName other = (ProductName) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }
    
    @Override
    public String toString() {
        return name;
    }
    /**
     * @return the name of the product name.
     */
    public String getName() {
        return name;
    }
    /**
     * Set the name of the product name.
     * @param name the name of the product name.
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * @return the products
     */
    public List<GeolocalisedProduct> getProducts() {
        return products;
    }

    /**
     * @param products the products to set
     */
    public void setProducts(final List<GeolocalisedProduct> products) {
        this.products = products;
    }
}
