/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.geolocation.business.entity;

import java.io.Serializable;
import java.util.List;
import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;

/**
 * The version of a geolocalized product.
 * 
 * @author mancelin
 */
@Entity
public class ProductVersion implements Serializable {
    /**
     * The version UID.
     */
    private static final long serialVersionUID = 1L;
    /**
     * The version of the product version.
     */
    private String version = "";
    /**
     * The id of the product version.
     */
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;
    /**
     * The concerned products.
     */
    @OneToMany(mappedBy = "productVersion",  cascade = CascadeType.REMOVE, fetch = FetchType.LAZY)
    private List<GeolocalisedProduct> products;
    /**
     * @return the id of the product version.
     */
    public Long getId() {
        return id;
    }
    /**
     * Set the id of the product version.
     * @param id the id of the product version.
     */
    public void setId(final Long id) {
        this.id = id;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        if (id != null) {
            hash += id.hashCode();
        } else {
            hash += 0;
        }
        return hash;
    }

    @Override
    public boolean equals(final Object object) {
        if (!(object instanceof ProductVersion)) {
            return false;
        }
        ProductVersion other = (ProductVersion) object;
        if ((this.id == null && other.id != null) || (this.id != null && !this.id.equals(other.id))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return version;
    }
    /**
     * Set the version of a product version.
     * @param version the version of a product version.
     */
    public void setVersion(final String version) {
        this.version = version;
    }
    /**
     * @return the version of a product version.
     */
    public String getVersion() {
        return version;
    }
    /**
     * @return the products
     */
    public List<GeolocalisedProduct> getProducts() {
        return products;
    }
    /**
     * @param products the products to set
     */
    public void setProducts(final List<GeolocalisedProduct> products) {
        this.products = products;
    }
}
